pub struct SubnetMetrics {
pub num_canisters: u64,
pub canister_state_bytes: u64,
pub consumed_cycles_total: u128,
pub update_transactions_total: u64,
}Expand description
A list of subnet metrics.
Fields
num_canisters: u64The number of canisters on this subnet.
canister_state_bytes: u64The total size of the state in bytes taken by canisters on this subnet since this subnet was created.
consumed_cycles_total: u128The total number of cycles consumed by all current and deleted canisters on this subnet.
update_transactions_total: u64The total number of transactions processed on this subnet since this subnet was created.